==> uproot-5.2.2.tar.gz: uproot-5.2.2/tests/test_0962_RNTuple_update.py <==
# BSD 3-Clause License; see https://github.com/scikit-hep/uproot5/blob/main/LICENSE

import pytest
import uproot
import awkward as ak
import skhep_testdata
import numpy as np


def test_new_support_RNTuple_split_int32_reading():
    with uproot.open(
        skhep_testdata.data_path("uproot_ntuple_int_5e4_629_01.root")
    ) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert len(df) == 5e4
        assert len(df.one_integers) == 5e4
        assert np.all(df.one_integers == np.arange(5e4 + 1)[::-1][:-1])


def test_new_support_RNTuple_bit_bool_reading():
    with uproot.open(skhep_testdata.data_path("uproot_ntuple_bit_629_01.root")) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert np.all(df.one_bit == np.asarray([1, 0, 0, 1, 0, 0, 1, 0, 0, 1]))


def test_new_support_RNTuple_split_int16_reading():
    with uproot.open(
        skhep_testdata.data_path("uproot_ntuple_int_multicluster_629_01.root")
    ) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert len(df.one_integers) == 1e8
        assert df.one_integers[0] == 2
        assert df.one_integers[-1] == 1
        assert np.all(np.unique(df.one_integers[: len(df.one_integers) // 2]) == [2])
        assert np.all(np.unique(df.one_integers[len(df.one_integers) / 2 + 1 :]) == [1])


pytest.importorskip("zstandard")


@pytest.mark.xfail(
    reason="Uproot can now read the data from event files (CMS/Atlas), but this test fails because the column matching logic is wrong.",
    strict=True,
)
def test_new_support_RNTuple_event_data():
    with uproot.open(
        "https://xrootd-local.unl.edu:1094//store/user/AGC/nanoaod-rntuple/zstd/TT_TuneCUETP8M1_13TeV-powheg-pythia8/cmsopendata2015_ttbar_19980_PU25nsData2015v1_76X_mcRun2_asymptotic_v12_ext3-v1_00000_0000.root"
    ) as f:
        obj = f["Events"]
        df = obj.arrays(["nTau"])
        assert len(df) == 1334428
        assert ak.to_list(df["nTau"][:10]) == [
            0,
            0,
            2,
            0,
            1,
            1,
            1,
            1,
            2,
            0,
        ]

==> uproot-5.3.0.tar.gz: uproot-5.3.0/tests/test_0962_RNTuple_update.py <==
# BSD 3-Clause License; see https://github.com/scikit-hep/uproot5/blob/main/LICENSE

import pytest
import uproot
import awkward as ak
import skhep_testdata
import numpy as np


def test_new_support_RNTuple_split_int32_reading():
    with uproot.open(
        skhep_testdata.data_path("uproot_ntuple_int_5e4_629_01.root")
    ) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert len(df) == 5e4
        assert len(df.one_integers) == 5e4
        assert np.all(df.one_integers == np.arange(5e4 + 1)[::-1][:-1])


def test_new_support_RNTuple_bit_bool_reading():
    with uproot.open(skhep_testdata.data_path("uproot_ntuple_bit_629_01.root")) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert np.all(df.one_bit == np.asarray([1, 0, 0, 1, 0, 0, 1, 0, 0, 1]))


def test_new_support_RNTuple_split_int16_reading():
    with uproot.open(
        skhep_testdata.data_path("uproot_ntuple_int_multicluster_629_01.root")
    ) as f:
        obj = f["ntuple"]
        df = obj.arrays()
        assert len(df.one_integers) == 1e8
        assert df.one_integers[0] == 2
        assert df.one_integers[-1] == 1
        assert np.all(np.unique(df.one_integers[: len(df.one_integers) // 2]) == [2])
        assert np.all(np.unique(df.one_integers[len(df.one_integers) / 2 + 1 :]) == [1])


pytest.importorskip("cramjam")


@pytest.mark.xfail(
    reason="Uproot can now read the data from event files (CMS/Atlas), but this test fails because the column matching logic is wrong.",
    strict=True,
)
def test_new_support_RNTuple_event_data():
    with uproot.open(
        "https://xrootd-local.unl.edu:1094//store/user/AGC/nanoaod-rntuple/zstd/TT_TuneCUETP8M1_13TeV-powheg-pythia8/cmsopendata2015_ttbar_19980_PU25nsData2015v1_76X_mcRun2_asymptotic_v12_ext3-v1_00000_0000.root"
    ) as f:
        obj = f["Events"]
        df = obj.arrays(["nTau"])
        assert len(df) == 1334428
        assert ak.to_list(df["nTau"][:10]) == [
            0,
            0,
            2,
            0,
            1,
            1,
            1,
            1,
            2,
            0,
        ]
